==> flake8-import-order-0.5.2.tar.gz: flake8-import-order-0.5.2/flake8_import_order/stdlib_list.py <==
STDLIB_NAMES = set((
    "abc",
    "aepack",
    "aetools",
    "aetypes",
    "aifc",
    "al",
    "AL",
    "anydbm",
    "argparse",
    "array",
    "ast",
    "asynchat",
    "asyncio",
    "asyncore",
    "atexit",
    "audioop",
    "autoGIL",
    "base64",
    "BaseHTTPServer",
    "Bastion",
    "bdb",
    "Binary",
    "binascii",
    "binhex",
    "bisect",
    "Boolean",
    "bsddb",
    "__builtin__",
    "builtins",
    "bz2",
    "calendar",
    "cd",
    "cgi",
    "CGIHTTPServer",
    "cgitb",
    "chunk",
    "cmath",
    "cmd",
    "code",
    "codecs",
    "codeop",
    "collections",
    "collections.abc",
    "ColorPicker",
    "colorsys",
    "commands",
    "compileall",
    "concurrent.futures",
    "configparser",
    "ConfigParser",
    "contextlib",
    "Cookie",
    "cookielib",
    "copy",
    "copy_reg",
    "copyreg",
    "cPickle",
    "crypt",
    "cStringIO",
    "csv",
    "ctypes",
    "curses",
    "curses.ascii",
    "curses.panel",
    "curses.textpad",
    "curses.wrapper",
    "datetime",
    "dbhash",
    "dbm",
    "decimal",
    "DEVICE",
    "difflib",
    "dircache",
    "dis",
    "distutils",
    "dl",
    "doctest",
    "DocXMLRPCServer",
    "dumbdbm",
    "_dummy_thread",
    "dummy_thread",
    "dummy_threading",
    "EasyDialogs",
    "email",
    "ensurepip",
    "enum",
    "errno",
    "faulthandler",
    "fcntl",
    "filecmp",
    "fileinput",
    "findertools",
    "fl",
    "FL",
    "flp",
    "fm",
    "fnmatch",
    "formatter",
    "fpectl",
    "fpformat",
    "fractions",
    "FrameWork",
    "ftplib",
    "functools",
    "__future__",
    "future_builtins",
    "gc",
    "gdbm",
    "gensuitemodule",
    "getopt",
    "getpass",
    "gettext",
    "gl",
    "GL",
    "glob",
    "grp",
    "gzip",
    "hashlib",
    "heapq",
    "hmac",
    "hotshot",
    "html",
    "html.entities",
    "htmlentitydefs",
    "htmllib",
    "html.parser",
    "HTMLParser",
    "http",
    "http.client",
    "http.cookiejar",
    "http.cookies",
    "httplib",
    "http.server",
    "ic",
    "imageop",
    "imaplib",
    "imgfile",
    "imghdr",
    "imp",
    "importlib",
    "imputil",
    "inspect",
    "io",
    "ipaddress",
    "itertools",
    "jpeg",
    "json",
    "keyword",
    "linecache",
    "locale",
    "logging",
    "logging.config",
    "logging.handlers",
    "lzma",
    "MacOS",
    "macostools",
    "macpath",
    "mailbox",
    "mailcap",
    "__main__",
    "Mapping",
    "marshal",
    "math",
    "md5",
    "mhlib",
    "mimetools",
    "mimetypes",
    "MimeWriter",
    "mimify",
    "MiniAEFrame",
    "mmap",
    "modulefinder",
    "msilib",
    "multifile",
    "multiprocessing",
    "mutex",
    "netrc",
    "new",
    "nis",
    "nntplib",
    "numbers",
    "Numeric",
    "operator",
    "optparse",
    "os",
    "os.path",
    "ossaudiodev",
    "parser",
    "pathlib",
    "pdb",
    "pickle",
    "pickletools",
    "pipes",
    "pkgutil",
    "platform",
    "plistlib",
    "popen2",
    "poplib",
    "posix",
    "posixfile",
    "pprint",
    "pty",
    "pwd",
    "pyclbr",
    "py_compile",
    "pydoc",
    "queue",
    "Queue",
    "quopri",
    "random",
    "re",
    "readline",
    "repr",
    "reprlib",
    "resource",
    "rexec",
    "rfc822",
    "rlcompleter",
    "robotparser",
    "runpy",
    "sched",
    "ScrolledText",
    "select",
    "Sequence",
    "Set",
    "sets",
    "sgmllib",
    "sha",
    "shelve",
    "shlex",
    "shutil",
    "signal",
    "SimpleHTTPServer",
    "SimpleXMLRPCServer",
    "site",
    "smtpd",
    "smtplib",
    "sndhdr",
    "socket",
    "socketserver",
    "SocketServer",
    "spwd",
    "sqlite3",
    "ssl",
    "stat",
    "statistics",
    "statvfs",
    "string",
    "StringIO",
    "stringprep",
    "struct",
    "subprocess",
    "sunau",
    "sunaudiodev",
    "SUNAUDIODEV",
    "symbol",
    "symtable",
    "sys",
    "sysconfig",
    "syslog",
    "tabnanny",
    "tarfile",
    "telnetlib",
    "tempfile",
    "termios",
    "test",
    "test.support",
    "test.test_support",
    "Text",
    "textwrap",
    "_thread",
    "thread",
    "threading",
    "time",
    "timeit",
    "Tix",
    "tkinter",
    "Tkinter",
    "tkinter.scrolledtext",
    "tkinter.tix",
    "tkinter.ttk",
    "token",
    "tokenize",
    "trace",
    "traceback",
    "tracemalloc",
    "ttk",
    "tty",
    "turtle",
    "types",
    "unicodedata",
    "unittest",
    "unittest.mock",
    "urllib",
    "urllib2",
    "urllib.error",
    "urllib.parse",
    "urllib.request",
    "urllib.response",
    "urllib.robotparser",
    "urlparse",
    "user",
    "UserDict",
    "UserList",
    "UserString",
    "uu",
    "uuid",
    "venv",
    "warnings",
    "wave",
    "weakref",
    "webbrowser",
    "whichdb",
    "winsound",
    "wsgiref",
    "xdrlib",
    "xml",
    "zipfile",
    "zipimport",
    "zlib",
))

==> flake8-import-order_0.18.1.orig.tar.gz: flake8-import-order-0.18.1/flake8_import_order/stdlib_list.py <==
STDLIB_NAMES = {
    "AL",
    "BaseHTTPServer",
    "Bastion",
    "Binary",
    "Boolean",
    "CGIHTTPServer",
    "ColorPicker",
    "ConfigParser",
    "Cookie",
    "DEVICE",
    "DocXMLRPCServer",
    "EasyDialogs",
    "FL",
    "FrameWork",
    "GL",
    "HTMLParser",
    "MacOS",
    "Mapping",
    "MimeWriter",
    "MiniAEFrame",
    "Numeric",
    "Queue",
    "SUNAUDIODEV",
    "ScrolledText",
    "Sequence",
    "Set",
    "SimpleHTTPServer",
    "SimpleXMLRPCServer",
    "SocketServer",
    "StringIO",
    "Text",
    "Tix",
    "Tkinter",
    "UserDict",
    "UserList",
    "UserString",
    "__builtin__",
    "__future__",
    "__main__",
    "_dummy_thread",
    "_thread",
    "_threading_local",
    "abc",
    "aepack",
    "aetools",
    "aetypes",
    "aifc",
    "al",
    "anydbm",
    "argparse",
    "array",
    "ast",
    "asynchat",
    "asyncio",
    "asyncore",
    "atexit",
    "audioop",
    "autoGIL",
    "base64",
    "bdb",
    "binascii",
    "binhex",
    "bisect",
    "bsddb",
    "builtins",
    "bz2",
    "cPickle",
    "cProfile",
    "cStringIO",
    "calendar",
    "cd",
    "cgi",
    "cgitb",
    "chunk",
    "cmath",
    "cmd",
    "code",
    "codecs",
    "codeop",
    "collections",
    "colorsys",
    "commands",
    "compileall",
    "concurrent",
    "configparser",
    "contextlib",
    "contextvars",
    "cookielib",
    "copy",
    "copy_reg",
    "copyreg",
    "crypt",
    "csv",
    "ctypes",
    "curses",
    "dataclasses",
    "datetime",
    "dbhash",
    "dbm",
    "decimal",
    "difflib",
    "dircache",
    "dis",
    "distutils",
    "dl",
    "doctest",
    "dumbdbm",
    "dummy_thread",
    "dummy_threading",
    "email",
    "encodings",
    "ensurepip",
    "enum",
    "errno",
    "faulthandler",
    "fcntl",
    "filecmp",
    "fileinput",
    "findertools",
    "fl",
    "flp",
    "fm",
    "fnmatch",
    "formatter",
    "fpectl",
    "fpformat",
    "fractions",
    "ftplib",
    "functools",
    "future_builtins",
    "gc",
    "gdbm",
    "gensuitemodule",
    "getopt",
    "getpass",
    "gettext",
    "gl",
    "glob",
    "grp",
    "gzip",
    "hashlib",
    "heapq",
    "hmac",
    "hotshot",
    "html",
    "htmlentitydefs",
    "htmllib",
    "http",
    "httplib",
    "ic",
    "imageop",
    "imaplib",
    "imgfile",
    "imghdr",
    "imp",
    "importlib",
    "imputil",
    "inspect",
    "io",
    "ipaddress",
    "itertools",
    "jpeg",
    "json",
    "keyword",
    "lib2to3",
    "linecache",
    "locale",
    "logging",
    "lzma",
    "macostools",
    "macpath",
    "macurl2path",
    "mailbox",
    "mailcap",
    "marshal",
    "math",
    "md5",
    "mhlib",
    "mimetools",
    "mimetypes",
    "mimify",
    "mmap",
    "modulefinder",
    "msilib",
    "multifile",
    "multiprocessing",
    "mutex",
    "netrc",
    "new",
    "nis",
    "nntplib",
    "ntpath",
    "nturl2path",
    "numbers",
    "operator",
    "optparse",
    "os",
    "os2emxpath",
    "ossaudiodev",
    "parser",
    "pathlib",
    "pdb",
    "pickle",
    "pickletools",
    "pipes",
    "pkgutil",
    "platform",
    "plistlib",
    "popen2",
    "poplib",
    "posix",
    "posixfile",
    "posixpath",
    "pprint",
    "profile",
    "pstats",
    "pty",
    "pwd",
    "py_compile",
    "pyclbr",
    "pydoc",
    "pyexpat",
    "queue",
    "quopri",
    "random",
    "re",
    "readline",
    "repr",
    "reprlib",
    "resource",
    "rexec",
    "rfc822",
    "rlcompleter",
    "robotparser",
    "runpy",
    "sched",
    "secrets",
    "select",
    "selectors",
    "sets",
    "sgmllib",
    "sha",
    "shelve",
    "shlex",
    "shutil",
    "signal",
    "site",
    "smtpd",
    "smtplib",
    "sndhdr",
    "socket",
    "socketserver",
    "spwd",
    "sqlite3",
    "ssl",
    "stat",
    "statistics",
    "statvfs",
    "string",
    "stringprep",
    "struct",
    "subprocess",
    "sunau",
    "sunaudiodev",
    "symbol",
    "symtable",
    "sys",
    "sysconfig",
    "syslog",
    "tabnanny",
    "tarfile",
    "telnetlib",
    "tempfile",
    "termios",
    "test",
    "textwrap",
    "thread",
    "threading",
    "time",
    "timeit",
    "tkinter",
    "token",
    "tokenize",
    "trace",
    "traceback",
    "tracemalloc",
    "ttk",
    "tty",
    "turtle",
    "turtledemo",
    "types",
    "typing",
    "unicodedata",
    "unittest",
    "urllib",
    "urllib2",
    "urlparse",
    "user",
    "uu",
    "uuid",
    "venv",
    "warnings",
    "wave",
    "weakref",
    "webbrowser",
    "whichdb",
    "winsound",
    "wsgiref",
    "xdrlib",
    "xml",
    "xmlrpc",
    "xmlrpclib",
    "zipapp",
    "zipfile",
    "zipimport",
    "zlib",
}
